#ifndef DATA_H
#define DATA_H

#include <QtCore/QObject>
#include <QtCore/QString>
#include <QtCore/QSize>
#include <QtCore/QList>
#include <QtGui/QImage>
#include <QtGui/QColor>
#include <QtCore/QFuture>
#include <QtCore/QFutureWatcher>

const int imageWidth = 8000;
const int imageHeight = 6000;
const int chunkLen = 100;
const int maxIterations = 2000;

static QColor palette[maxIterations+1];

class Data : public QObject
{
  Q_OBJECT
  
  private:
    QImage *image;
    QList<int> chunkList;
    QFuture<QImage> mandelImage;
    QFutureWatcher<QImage> *mandelWatcher;
        
  public:
    Data(QObject* parent=0);
    ~Data();
    void initPalette();
    QImage * getImage();
    QSize getImageSize();
    void saveImage(QString fileName);
    void scaleImage(double scale);
    void initChunkList();
    void calcMandelBrot();
    
  signals:
    void mandelReady();  
    void mandelStatus(int value);
    
  public slots:
    void mandelFinished();  
    void mandelProgress(int value);
};
  
#endif
